@@ -1,4 +1,20 @@
-/* child.c */
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
 
 #include "gnome_chess.h"
 #include <ctype.h>
@@ -7,12 +23,10 @@
 #include <signal.h>
 
 #include "portab.h"
-#include "cho1.h"
 #include "pro.h"
-#include "position.h"
 #include "child.h"
 
-int start_child(char *cmd, char *arg, FILE **readpipe, FILE **writepipe,pid_t *childpid)
+int start_child(char *cmd, char **arg, FILE **readpipe, FILE **writepipe,pid_t *childpid)
 {
 int pipe1[2],pipe2[2];
 
@@ -49,11 +63,8 @@ else   /* Child */
     close(pipe1[0]);
     close(pipe2[1]);
 
-    if (debug)
-      fprintf (stderr,"cmd: %s %s\n",cmd,arg);
-
-    if (execlp(cmd,cmd,arg,NULL) <0)
-      perror("execlp");
+    if (execvp(cmd,arg) <0)
+      perror("execvp");
     return 0;
   }
 
@@ -73,4 +84,4 @@ int stop_child(pid_t childpid)
      return 1;
    }
  return 0;
-}
\ No newline at end of file
+}
