@@ -1,3 +1,21 @@
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include "gnome_chess.h"
 #include <ctype.h>
 #include "portab.h"
@@ -106,7 +124,7 @@ void ascii_to_move(char *p, int *from, int *to)
     {
       if (!strcmp(p,"o-o-o"))
 	{
-	  if (currPositionPtr->amzug == WMOVE)
+	  if (currPositionPtr->tomove == WMOVE)
 	    {
 	      *from = E1;
 	      *to   = C1;
@@ -118,7 +136,7 @@ void ascii_to_move(char *p, int *from, int *to)
 	    }
 	}
       else
-	if (currPositionPtr->amzug == WMOVE)
+	if (currPositionPtr->tomove == WMOVE)
 	  {
 	    *from = E1;
 	    *to   = G1;
