@@ -23,6 +23,7 @@
 #include <signal.h>
 
 #include "makros.h"
+#include "zvt.h"
 #include "portab.h"
 #include "child.h"
 #include "cho1.h"
@@ -48,8 +49,13 @@ static void engine_local_cblack_cb (GtkWidget *widget, void *data);
 
 struct engine * engine_local_new(char *cmd, char *arg) {
 	struct engine *e;
+	char *argv[3];
 
-	e = engine_new(cmd, arg);
+	argv[0]=cmd;
+	argv[1]=arg;
+	argv[2]=NULL;
+
+	e = engine_new(cmd, argv);
 	engine_local_menu_init(e);
 
 	gdk_input_add( fileno(e->read_from), GDK_INPUT_READ, engine_local_cb, e);
@@ -97,7 +103,7 @@ static void engine_local_move(char *p)
 	    gnomechess_position_make_move(currPositionPtr,from,to);
 	    gnomechess_sound_enginemove();
 	    gnomechess_movelist_add(board.movelist, piece,from,to);
-	    update_board();
+	    gnomechess_board_update();
 }
 
 static void
@@ -106,7 +112,7 @@ engine_local_new_cb (GtkWidget *widget, void *data)
   engine_write(first_chess_programm,"new\n");
   gnomechess_position_set_initial(currPositionPtr);
   gnomechess_movelist_clear(board.movelist);
-  update_board();
+  gnomechess_board_update();
 }
 
 static void engine_local_takeback_cb (GtkWidget *widget, void *data) {
@@ -128,7 +134,7 @@ static void engine_local_takeback_cb (GtkWidget *widget, void *data) {
 	}
 
 	gnomechess_movelist_clear_from(board.movelist, curr);
-	update_board();
+	gnomechess_board_update();
 }
 
 static void
@@ -147,25 +153,22 @@ static void engine_local_resign_cb (GtkWidget *widget, void *data) {
 
 static void engine_local_start_cb (GtkWidget *widget, void *data) {
   gnomechess_movelist_move_start(board.movelist);
-  update_board();
-  return;
+  gnomechess_board_update();
 }
 
 static void engine_local_previous_cb (GtkWidget *widget, void *data) {
   gnomechess_movelist_move_back(board.movelist);
-  update_board();
-  return;
+  gnomechess_board_update();
 }
 
 static void engine_local_next_cb (GtkWidget *widget, void *data) {
   gnomechess_movelist_move_forward(board.movelist);
-  update_board();
-  return;
+  gnomechess_board_update();
 }
 
 static void engine_local_end_cb (GtkWidget *widget, void *data) {
   gnomechess_movelist_move_end(board.movelist);
-  update_board();
+  gnomechess_board_update();
 }
 
 static void engine_local_now_cb (GtkWidget *widget, void *data) {
@@ -177,19 +180,25 @@ static void engine_local_go_cb (GtkWidget *widget, void *data) {
 }
 
 static void engine_local_cwhite_cb (GtkWidget *widget, void *data) {
+
 	engine_write(first_chess_programm,"white\n");
-	if (currPositionPtr->amzug == WMOVE)
+
+	if (currPositionPtr->tomove == WMOVE)
 		engine_write(first_chess_programm,"go\n");
-	set_flip(TRUE);
-	update_board();
+
+	gnomechess_board_set_flip(TRUE);
+	gnomechess_board_update();
 }
 
 static void engine_local_cblack_cb (GtkWidget *widget, void *data) {
+
 	engine_write(first_chess_programm,"black\n");
-	if (currPositionPtr->amzug == BMOVE)
+
+	if (currPositionPtr->tomove == BMOVE)
 		engine_write(first_chess_programm,"go\n");
-	set_flip(FALSE);
-	update_board();
+
+	gnomechess_board_set_flip(FALSE);
+	gnomechess_board_update();
 }
 
 void engine_local_cb( gpointer data, gint source, GdkInputCondition condition)
@@ -219,20 +228,17 @@ void engine_local_cb( gpointer data, gint source, GdkInputCondition condition)
       if (debug)
        fputs(buf,stderr);
 
-      gtk_text_insert (GTK_TEXT(board.messages), NULL,
-                    0,
-		    NULL,
-                    buf, -1);
+      zvt_print_raw_text(board.messages, buf);
+
       *q=0;
       *(q+1) = tmp;
 
-      // parse for  NUMBER ... MOVE  
-  
+      /* parse for  NUMBER ... MOVE */
       if (isdigit(*buf))
 	if ((p = strstr(buf,"...")))
 	    engine_local_move(p+4);
 
-      // parse for move MOVE
+      /* parse for move MOVE */
       if (!strncmp("move",buf,4))
 	    engine_local_move(buf+5);
 
