@@ -269,7 +269,7 @@ void disable_menu(gint item) {
 
 void menu_load_cb (GtkWidget *widget, void *data) {
   load_game();
-  update_board();
+  gnomechess_board_update();
   return;
 }
 
@@ -358,7 +358,7 @@ void menu_prefs_cb (GtkWidget *widget, void *data) {
 void menu_about_cb (GtkWidget *widget, void *data) {
   GtkWidget *about;
   const  gchar *authors[] = {
-	  N_("Robert Wilhelm <robert@physiol.med.tu-muenchen.de>"),
+	  N_("Robert Wilhelm <robert.wilhelm@gmx.net>"),
 	  N_("JP Rosevear <jpr@arcavia.com>"),
           NULL
           };
