@@ -81,7 +81,7 @@ static WORD reg_zug_umw(WORD nach,WORD n1,WORD n2,WORD n3,WORD n4)
         BYTE help;
         WORD fi=0,c;
 
-        if  (currPositionPtr->amzug == WMOVE)
+        if  (currPositionPtr->tomove == WMOVE)
                     help = nach - A8;
         else
                     help = nach - A1;
@@ -90,7 +90,7 @@ static WORD reg_zug_umw(WORD nach,WORD n1,WORD n2,WORD n3,WORD n4)
         if ( help == (n1 & 7)) 
         {
 	  c= promotion_dialog();
-	  if (currPositionPtr->amzug == WMOVE) 
+	  if (currPositionPtr->tomove == WMOVE) 
 	    switch (c) 
 	      {
 	      case 0 : fi = WQ;break;
@@ -107,7 +107,7 @@ static WORD reg_zug_umw(WORD nach,WORD n1,WORD n2,WORD n3,WORD n4)
 	      case 3 : fi = BN;break;
 	      }
 
-	  if (currPositionPtr->amzug == WMOVE)
+	  if (currPositionPtr->tomove == WMOVE)
 	    help = 128 + nach - A8 + (fi - WP + 1) * 8;
 	  else
 	    help = 128 + nach - A1 + (fi - BP + 1) * 8;
@@ -125,14 +125,13 @@ static WORD reg_zug_umw(WORD nach,WORD n1,WORD n2,WORD n3,WORD n4)
         return FALSE;
 }
 
-WORD legal_move(BYTE **zl,WORD *as,WORD *an)
-{
-position temp;
-WORD a;
-BYTE *ap,*ap2;
-WORD anz,anz_s,anz_n,anzahl,schach=0;
-WORD amzug = currPositionPtr->amzug;
-BYTE zugl[AB_ZUGL];
+WORD legal_move(BYTE **zl,WORD *as,WORD *an) {
+	position temp;
+	WORD a;
+	BYTE *ap,*ap2;
+	WORD anz,anz_s,anz_n,anzahl,check=0;
+	WORD amzug = currPositionPtr->tomove;
+	BYTE zugl[AB_ZUGL];
 
         ap =  zugl + AB_ZUG_S;
         anz = move_generator(&ap,&anz_s,&anz_n);
@@ -147,30 +146,26 @@ BYTE zugl[AB_ZUGL];
 
                 switch (amzug)
                 {
-                        case WMOVE: schach = king_is_attacked_white();
+                        case WMOVE: check = king_is_attacked_white();
                                   break;
-                        case BMOVE: schach = king_is_attacked_black();
+                        case BMOVE: check = king_is_attacked_black();
                                   break;
                         default : abort();
                 }
 
-                if (!schach)
-                {
+                if (!check) {
                         *ap2++=*ap++;
                         *ap2++=*ap++;
                         anzahl++;
-                }
-                else    
-		{
+                } else {
 		        ap+=2;
 		}
-                switch (amzug)
-                {
+                switch (amzug) {
                         case WMOVE:
-                                rueck_w(*(ap-2),*(ap-1));
+                                gnomechess_position_move_reverse_white(currPositionPtr,*(ap-2),*(ap-1));
                                 break;
                         case BMOVE:
-                                rueck_s(*(ap-2),*(ap-1));
+                                gnomechess_position_move_reverse_black(currPositionPtr,*(ap-2),*(ap-1));
                                 break;
                 }
                 *currPositionPtr = temp;
