@@ -1,3 +1,21 @@
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <glib.h>
 
 #include "portab.h"
@@ -5,14 +23,11 @@
 #include "position.h"
 #include "pro.h"
 
-
-
 static const int jump[]={ 8, 12,19, 21,-8,-12,-19,-21,     
                    9, 11,-9,-11, 1, 10,-10, -1,     
                    9, 11, 1, 10,-1,  1, 10, -1,
                   -9,-11, 1,-10,-1     };
 
-
 static BYTE *index,*sindex;
 
 static void sdouble(WORD af,WORD a,WORD b);
@@ -670,9 +685,9 @@ static int movgen_black(BYTE **index0,WORD *anz_s,WORD *anz_n)
 int  move_generator(BYTE **index0,WORD *anz_s,WORD *anz_n)
 {
 
-	if (currPositionPtr->amzug == WMOVE ) 
+	if (currPositionPtr->tomove == WMOVE ) 
 		return movgen_white(index0,anz_s,anz_n);
-	else if (currPositionPtr->amzug == BMOVE ) 
+	else if (currPositionPtr->tomove == BMOVE ) 
 		return  movgen_black(index0,anz_s,anz_n);
     else
         abort();
