@@ -82,7 +82,7 @@ MoveList* gnomechess_movelist_new() {
 	gtk_container_add(GTK_CONTAINER(scrolled_window), clist);
 	gtk_widget_show(clist);
 
-	result = gtk_label_new(_(""));
+	result = gtk_label_new("");
 	gtk_widget_show(result);
 	gtk_box_pack_start(GTK_BOX(vbox), result, TRUE, TRUE, 0);
 
@@ -224,7 +224,7 @@ gnomechess_movelist_select_move
 
 	if (column == 1 || column == 2){
 		gnomechess_movelist_movetoply(board.movelist, row * 2 + column);
-		update_board();
+		gnomechess_board_update();
 	}	
 }
 
