@@ -772,7 +772,7 @@ select_game(GtkWidget * widget,int row,int column,GdkEventButton * event,GList *
 		gtk_clist_get_text(GTK_CLIST(widget), row, 2, &text );
 		gnomechess_movelist_set_result(board.movelist, text);
 
-		update_board();
+		gnomechess_board_update();
     }
 }
 
